@@ -186,68 +186,104 @@ def run_cat_report(output_dir, ticker, df):
     yy_visuals_sheet.write("A1", "Data", border_format)
     yy_visuals_sheet.write("B1", ticker + " Dollars %YY", border_format)
     yy_visuals_sheet.write("A2", "Best Category (Revenue)", border_format)
-    yy_visuals_sheet.write("B2", yy_best_rev_cat, border_format)
+    if use_rev:
+        yy_visuals_sheet.write("B2", yy_best_rev_cat, border_format)
+    else:
+        yy_visuals_sheet.write("B2", "Unavailable", border_format)
     yy_visuals_sheet.write("A3", "Best Category (Profit)", border_format)
-    yy_visuals_sheet.write("B3", yy_best_profit_cat, border_format)
+    if use_profit:
+        yy_visuals_sheet.write("B3", yy_best_profit_cat, border_format)
+    else:
+        yy_visuals_sheet.write("B3", "Unavailable", border_format)
     yy_visuals_sheet.write("A4", "Best Category (EPS)", border_format)
-    yy_visuals_sheet.write("B4", yy_best_eps_cat, border_format)
+    if use_eps:
+        yy_visuals_sheet.write("B4", yy_best_eps_cat, border_format)
+    else:
+        yy_visuals_sheet.write("B4", "Unavailable", border_format)
 
     #correlations table
     yy_visuals_sheet.write("E1","Category Corr.", border_format)
     yy_visuals_sheet.write("F1","Total NPD Corr.", border_format)
     yy_visuals_sheet.write("G1", "Consensus Corr.", border_format)
+    yy_visuals_sheet.write("H1", "Share of Total NPD $", border_format)
     yy_visuals_sheet.write("D2","Revenue", border_format)
     yy_visuals_sheet.write("D3","Profit", border_format)
     yy_visuals_sheet.write("D4","EPS", border_format)
-    if yy_rev_cat_corr > yy_rev_est_corr:
-        yy_visuals_sheet.write("E2",yy_rev_cat_corr, beat_consensus_format)
-    elif yy_rev_cat_corr > yy_rev_total_corr:
-        yy_visuals_sheet.write("E2",yy_rev_cat_corr, beat_total_dollars_format)
+
+    if use_rev:
+        if yy_rev_cat_corr > yy_rev_est_corr:
+            yy_visuals_sheet.write("E2",yy_rev_cat_corr, beat_consensus_format)
+        elif yy_rev_cat_corr > yy_rev_total_corr:
+            yy_visuals_sheet.write("E2",yy_rev_cat_corr, beat_total_dollars_format)
+        else:
+            yy_visuals_sheet.write("E2",yy_rev_cat_corr, border_format)
+        yy_visuals_sheet.write("F2", yy_rev_total_corr, rounded_border_format)
+        yy_visuals_sheet.write("G2",yy_rev_est_corr, rounded_border_format)
+        yy_visuals_sheet.write("H2", share_percs[yy_best_rev_cat], percent_border_format)
     else:
-        yy_visuals_sheet.write("E2",yy_rev_cat_corr, border_format)
-    if yy_profit_cat_corr > yy_profit_total_corr:
-        yy_visuals_sheet.write("E3",yy_profit_cat_corr, beat_total_dollars_format)
+        yy_visuals_sheet.write("E2", "Unavailable", border_format)
+        yy_visuals_sheet.write("F2", "Unavailable", rounded_border_format)
+        yy_visuals_sheet.write("G2", "Unavailable", rounded_border_format)
+        yy_visuals_sheet.write("H2", "Unavailable", percent_border_format)
+    
+    if use_profit:
+        if yy_profit_cat_corr > yy_profit_total_corr:
+            yy_visuals_sheet.write("E3",yy_profit_cat_corr, beat_total_dollars_format)
+        else:
+            yy_visuals_sheet.write("E3",yy_profit_cat_corr, border_format)
+        yy_visuals_sheet.write("F3", yy_profit_total_corr, rounded_border_format)
+        yy_visuals_sheet.write("H3", share_percs[yy_best_profit_cat], percent_border_format)
     else:
-        yy_visuals_sheet.write("E3",yy_profit_cat_corr, border_format)
-    if yy_eps_cat_corr > yy_eps_est_corr:
-        yy_visuals_sheet.write("E4", yy_eps_cat_corr, beat_consensus_format)
-    elif yy_eps_cat_corr > yy_eps_total_corr:
-        yy_visuals_sheet.write("E4", yy_eps_cat_corr, beat_total_dollars_format)
-    else:
-        yy_visuals_sheet.write("E4", yy_eps_cat_corr, rounded_border_format)
-    yy_visuals_sheet.write("F2", yy_rev_total_corr, rounded_border_format)
-    yy_visuals_sheet.write("F3", yy_profit_total_corr, rounded_border_format)
-    yy_visuals_sheet.write("F4", yy_eps_total_corr, rounded_border_format)
-    yy_visuals_sheet.write("G2",yy_rev_est_corr, rounded_border_format)
+        yy_visuals_sheet.write("E3", "Unavailable", border_format)
+        yy_visuals_sheet.write("F3", "Unavailable", rounded_border_format)
+        yy_visuals_sheet.write("H3", "Unavailable", percent_border_format)
     yy_visuals_sheet.write("G3", "N/A", border_format)
-    yy_visuals_sheet.write("G4", yy_eps_est_corr, rounded_border_format)
-    yy_visuals_sheet.write("H1", "Share of Total NPD $", border_format)
-    yy_visuals_sheet.write("H2", share_percs[yy_best_rev_cat], percent_border_format)
-    yy_visuals_sheet.write("H3", share_percs[yy_best_profit_cat], percent_border_format)
-    yy_visuals_sheet.write("H4", share_percs[yy_best_eps_cat], percent_border_format)
+    
+    if use_eps:
+        if yy_eps_cat_corr > yy_eps_est_corr:
+            yy_visuals_sheet.write("E4", yy_eps_cat_corr, beat_consensus_format)
+        elif yy_eps_cat_corr > yy_eps_total_corr:
+            yy_visuals_sheet.write("E4", yy_eps_cat_corr, beat_total_dollars_format)
+        else:
+            yy_visuals_sheet.write("E4", yy_eps_cat_corr, rounded_border_format)
+        yy_visuals_sheet.write("F4", yy_eps_total_corr, rounded_border_format)
+        yy_visuals_sheet.write("G4", yy_eps_est_corr, rounded_border_format)
+        yy_visuals_sheet.write("H4", share_percs[yy_best_eps_cat], percent_border_format)
+    else:
+        yy_visuals_sheet.write("E4", "Unavailable", rounded_border_format)
+        yy_visuals_sheet.write("F4", "Unavailable", rounded_border_format)
+        yy_visuals_sheet.write("G4", "Unavailable", rounded_border_format)
+        yy_visuals_sheet.write("H4", "Unavailable", percent_border_format)
+
 
     for col, size in {0:22, 1:29, 4:14, 5:18, 6:15, 7:18}.items():
         yy_visuals_sheet.set_column(col, col, size)
 
     yy_x_axis = ["YY Data",1, yy_cols.index("quarter_end"), len(sdf_yy), yy_cols.index("quarter_end")]
 
-    yy_rev_cat_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), yy_best_rev_cat, REVENUE_REPORT, "Reported Revenue", yy_x_axis, len(sdf_yy))
-    yy_rev_total_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "total_dollars", REVENUE_REPORT, "Reported Revenue", yy_x_axis, len(sdf_yy))
-    yy_rev_consenesus_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "BEST_SALES", REVENUE_REPORT, "Reported Revenue", yy_x_axis, len(sdf_yy))
-    yy_profit_cat_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), yy_best_profit_cat, PROFIT_REPORT, "Reported Profit", yy_x_axis, len(sdf_yy))
-    yy_profit_total_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "total_dollars", PROFIT_REPORT, "Reported Profit", yy_x_axis, len(sdf_yy))
-    yy_eps_cat_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), yy_best_eps_cat, EPS_REPORT, "Reported EPS", yy_x_axis, len(sdf_yy))
-    yy_eps_total_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "total_dollars", EPS_REPORT, "Reported EPS", yy_x_axis, len(sdf_yy))
-    yy_eps_consenesus_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "BEST_EPS", EPS_REPORT, "Reported EPS", yy_x_axis, len(sdf_yy))
+    if use_rev:
+        yy_rev_cat_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), yy_best_rev_cat, REVENUE_REPORT, "Reported Revenue", yy_x_axis, len(sdf_yy))
+        yy_rev_total_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "total_dollars", REVENUE_REPORT, "Reported Revenue", yy_x_axis, len(sdf_yy))
+        yy_rev_consenesus_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "BEST_SALES", REVENUE_REPORT, "Reported Revenue", yy_x_axis, len(sdf_yy))
+    if use_profit:
+        yy_profit_cat_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), yy_best_profit_cat, PROFIT_REPORT, "Reported Profit", yy_x_axis, len(sdf_yy))
+        yy_profit_total_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "total_dollars", PROFIT_REPORT, "Reported Profit", yy_x_axis, len(sdf_yy))
+    if use_eps:
+        yy_eps_cat_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), yy_best_eps_cat, EPS_REPORT, "Reported EPS", yy_x_axis, len(sdf_yy))
+        yy_eps_total_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "total_dollars", EPS_REPORT, "Reported EPS", yy_x_axis, len(sdf_yy))
+        yy_eps_consenesus_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "BEST_EPS", EPS_REPORT, "Reported EPS", yy_x_axis, len(sdf_yy))
 
-    yy_visuals_sheet.insert_chart("A6", yy_rev_cat_chart)
-    yy_visuals_sheet.insert_chart("E6", yy_rev_total_chart)
-    yy_visuals_sheet.insert_chart("J6", yy_rev_consenesus_chart, {'x_offset': -44})
-    yy_visuals_sheet.insert_chart("A21", yy_profit_cat_chart)
-    yy_visuals_sheet.insert_chart("E21", yy_profit_total_chart)
-    yy_visuals_sheet.insert_chart("A36", yy_eps_cat_chart)
-    yy_visuals_sheet.insert_chart("E36", yy_eps_total_chart)
-    yy_visuals_sheet.insert_chart("J36", yy_eps_consenesus_chart, {'x_offset': -44})
+    if use_rev:
+        yy_visuals_sheet.insert_chart("A6", yy_rev_cat_chart)
+        yy_visuals_sheet.insert_chart("E6", yy_rev_total_chart)
+        yy_visuals_sheet.insert_chart("J6", yy_rev_consenesus_chart, {'x_offset': -44})
+    if use_profit:
+        yy_visuals_sheet.insert_chart("A21", yy_profit_cat_chart)
+        yy_visuals_sheet.insert_chart("E21", yy_profit_total_chart)
+    if use_eps:
+        yy_visuals_sheet.insert_chart("A36", yy_eps_cat_chart)
+        yy_visuals_sheet.insert_chart("E36", yy_eps_total_chart)
+        yy_visuals_sheet.insert_chart("J36", yy_eps_consenesus_chart, {'x_offset': -44})
 
     writer.save()
     writer.close()
